@@ -3,7 +3,7 @@
 #
 
 import requests
-
+from requests.exceptions import HTTPError
 
 class BaseAPI:
     """Base class for HTTP API calls."""
@@ -18,7 +18,11 @@ class BaseAPI:
 
     def _send_request(self, request_handler, url, **kwargs):
         response = request_handler('{0}{1}'.format(self.host, url), headers=self.headers, **kwargs)
-        response.raise_for_status()
+        try:
+            response.raise_for_status()
+        except HTTPError as e:
+            e.args = e.args + (response.text,)
+            raise e
         return response.json()
 
     def get(self, url: str, params: dict = None):
