@@ -4,13 +4,15 @@
 
 from pinecone.network.zmq import SocketType
 from pinecone.protos import core_pb2
-from pinecone.utils import module_name, get_memory_usage
-from pinecone.utils.constants import PERSISTENT_VOLUME_MOUNT, MEMORY_LIMIT_MB, NodeType
+from pinecone.utils import module_name, get_container_memory_usage
+from pinecone.utils.constants import PERSISTENT_VOLUME_MOUNT, MEMORY_LIMIT_BYTES, NodeType
+from pinecone.utils import logger
 
 import os.path, os
 import json
 import argparse
-from typing import Dict, Union, Optional
+import asyncio
+from typing import Dict, Optional
 
 
 class Function:
@@ -42,7 +44,7 @@ class Function:
                 '--replicas', str(self.replicas),
                 '--shards', str(self.shards),
                 '--name', str(self.name),
-                '--node_type', json.loads(json.dumps(self._node_type))]
+                '--node_type', self._node_type.value]
 
     @classmethod
     def add_args(cls, parser: argparse.ArgumentParser):
@@ -50,7 +52,7 @@ class Function:
         parser.add_argument('--replicas', type=int, help='total number of replicas', default='1')
         parser.add_argument('--shards', type=int, help='total number of shards', default='1')
         parser.add_argument('--name', type=str, help='functions name')
-        parser.add_argument('--node_type', type=str, help='type of node to schedule function on', default='STANDARD')
+        parser.add_argument('--node_type', type=str, help='type of node to schedule function on', default=NodeType.STANDARD.value)
 
     def __init__(self,
                  in_sock_type: SocketType = SocketType.PULL,
@@ -116,10 +118,22 @@ class Function:
     @id.setter
     def id(self, value: int):
         self._id = value
-    
-    def get_stats(self) -> Dict[str, Union[int, float, str]]:
+
+    @property
+    def stats_frequency_seconds(self):
+        return 0
+
+    def get_stats(self) -> Dict:
         return {}
 
+    async def export_stats(self):
+        if self.stats_frequency_seconds == 0:
+            return
+        while True:
+            await asyncio.sleep(self.stats_frequency_seconds)
+            stats = self.get_stats()
+            logger.opt(raw=True).info(json.dumps({"recordType": "functionStats", "name": self.name, **stats}) + "\n")
+
     def to_dict(self):
         return {
             'name': self.name,
@@ -132,14 +146,14 @@ class Function:
         """
         :return: Requested memory resources in mb
         """
-        return 500
+        return 300
 
     @property
     def cpu_request(self) -> int:
         """
         :return: Request CPU in 1/1000th of a core
         """
-        return 2000 if self._node_type == NodeType.COMPUTE else 500
+        return 300
 
     @property
     def volume_request(self) -> Optional[int]:
@@ -159,9 +173,9 @@ class Function:
 
     @property
     def full(self) -> bool:
-        if MEMORY_LIMIT_MB == 0:  # no limit
+        if MEMORY_LIMIT_BYTES == 0:
             return False
-        return get_memory_usage() > (MEMORY_LIMIT_MB * 1E6)
+        return get_container_memory_usage() > MEMORY_LIMIT_BYTES
 
     def cleanup(self):
         pass
