@@ -38,5 +38,5 @@ class ShardSelector(SocketSelector):
     def select_socket(cls, msg: 'core_pb2.Request', shards: int) -> List[Optional['core_pb2.Request']]:
         req_type = msg.WhichOneof('body')
         if req_type in ['info', 'query', 'fetch'] or shards <= 1:
-            return [msg] * shards
+            return [msg]
         return ShardSelector.shard_msg(msg, req_type, shards)
