@@ -14,7 +14,8 @@ import asyncio
 from typing import Awaitable, Callable, List
 
 
-def start(servlet_spec: ServletSpec, volume_request=None, persistent_dir=None, num_replicas=None, sync_handler=None):
+def start(servlet_spec: ServletSpec, volume_request=None, persistent_dir=None, num_replicas=None, sync_msg_handler=None,
+          stats_exporter=None):
     logger.info('starting zmq servlet: %s ' % servlet_spec.function_name)
 
     try:
@@ -27,12 +28,15 @@ def start(servlet_spec: ServletSpec, volume_request=None, persistent_dir=None, n
         servlet = WALServlet(servlet_spec, num_replicas, persistent_dir, volume_request=volume_request)
         logger.info(f"Before reload: {servlet_spec.get_stats()}")
         servlet.write_offset(servlet.replica, 0)  # replay all the messages
-        request_backlog = list(servlet.load_sync(sync_handler))
+        servlet.load_sync(sync_msg_handler)
         logger.info(f"After reload: {servlet_spec.get_stats()}")
         loop.create_task(servlet.consume_msgs())
     else:
         servlet = ZMQServlet(servlet_spec)
 
+    if stats_exporter:
+        loop.create_task(stats_exporter())
+
     servlet.start_polling()
     servlet.refresh_dns()
     loop.run_forever()
@@ -90,6 +94,11 @@ async def recv_logs(servlet: WALServlet, num: int):
     return msgs
 
 
+async def send_replay_request(servlet: WALServlet, offset: int, total_num: int):
+    await servlet.send_log_msg(servlet.get_replay_request(override_offset=offset), 0)
+    await recv_logs(servlet, total_num)
+
+
 async def send_logs(servlet: WALServlet, log: List['core_pb2.LogEntry'], replica: int):
     for msg in log:
         await servlet.send_log_msg(msg, replica)
