@@ -26,6 +26,9 @@ class Spec:
     def to_obj(self) -> dict:
         raise NotImplementedError
 
+    def validate(self):
+        pass
+
     @classmethod
     def from_json(cls, spec: str) -> "Spec":
         """Creates class instance from json string."""
